import { arrow as arrowCore } from "@floating-ui/core";
import { autoUpdate as _autoUpdate, computePosition } from "@floating-ui/dom";
import { get } from "svelte/store";
export function createFloatingActions(initOptions) {
    let referenceElement;
    let floatingElement;
    let options = initOptions;
    const updatePosition = (updateOptions) => {
        if (referenceElement && floatingElement) {
            options = { ...initOptions, ...updateOptions };
            computePosition(referenceElement, floatingElement, options)
                .then(v => {
                Object.assign(floatingElement.style, {
                    position: v.strategy,
                    left: `${v.x}px`,
                    top: `${v.y}px`,
                });
                options?.onComputed && options.onComputed(v);
            });
        }
    };
    const referenceAction = node => {
        referenceElement = node;
        updatePosition();
    };
    const contentAction = (node, contentOptions) => {
        let autoUpdateDestroy;
        floatingElement = node;
        options = { ...initOptions, ...contentOptions };
        updatePosition();
        if (options.autoUpdate !== false) {
            autoUpdateDestroy = _autoUpdate(referenceElement, floatingElement, () => updatePosition(), options.autoUpdate);
        }
        return {
            update: updatePosition,
            destroy() {
                autoUpdateDestroy && autoUpdateDestroy();
            }
        };
    };
    return [
        referenceAction,
        contentAction,
        updatePosition
    ];
}
export function arrow(options) {
    return {
        name: "arrow",
        options,
        fn(args) {
            const element = get(options.element);
            if (element) {
                return arrowCore({
                    element,
                    padding: options.padding
                }).fn(args);
            }
            return {};
        }
    };
}
